//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>          // part specific constants and macros
#include "PSoCAPI.h"      // PSoC API definitions for all User Modules

#include "driverdecl.h"
#include "CMXSystem.h"
#include "CMXSystemExtern.h"
#include "TransferFunction.h"

#include "cmx.h"
#include "ProjectProperties.h"
#include "Custom.h"

// Channel includes


void main()
{
    // Initialize Project
    M8C_EnableGInt;                            // Turn on interrupts 
    I2C_CFG &= 0xFC;                           // Disable I2C in case it's not used.
    SystemTimer_Start();
    SystemTimer_SetInterval(SystemTimer_64_HZ);
    SystemTimer_EnableInt();

    // Initialize Channels


    // Initialize Variables
	SystemVars.ReadOnlyVars.pse_Button0 = 0;
	SystemVars.ReadOnlyVars.pse_LED_Blink = 0;
	SystemVars.ReadOnlyVars.pse_LED_Decay = 0;
	SystemVars.ReadOnlyVars.pse_LED_OnOff = 0;

    // Driver instantiations
CMX_GSWITCH_Instantiate(&pse_Button0);
CMX_DIO_Instantiate(&pse_LED_OnOff);
CMX_DIO_SetValue(&pse_LED_OnOff, (BYTE)SystemVars.ReadOnlyVars.pse_LED_OnOff);
CMX_BLINKINGLED_Instantiate(&pse_LED_Blink);
CMX_BLINKINGLED_SetValue(&pse_LED_Blink, (BYTE)SystemVars.ReadOnlyVars.pse_LED_Blink);
CMX_PULSELED_Instantiate(&pse_LED_Decay);

    // Custom initization code.
    CustomInit();
    // End Initialize Project

	while(1)
	{
        // Sync loop sample rate
#if ( SAMPLE_DIVIDER  )
        SystemTimer_SyncWait(SAMPLE_DIVIDER, SystemTimer_WAIT_RELOAD);
#endif
		// update input variables
		SystemVars.ReadOnlyVars.pse_Button0 = CMX_GSWITCH_GetValue(&pse_Button0);

        // Custom Post Input function
        CustomPostInputUpdate();

		// run transfer function and update output variables
		TransferFunction();

        // CustomPreOutputUpdate();
        CustomPreOutputUpdate();

		// set outputs
		CMX_BLINKINGLED_SetValue(&pse_LED_Blink, (BYTE)SystemVars.ReadOnlyVars.pse_LED_Blink);
		CMX_PULSELED_SetValue(&pse_LED_Decay, (BYTE)SystemVars.ReadOnlyVars.pse_LED_Decay);
		CMX_DIO_SetValue(&pse_LED_OnOff, (BYTE)SystemVars.ReadOnlyVars.pse_LED_OnOff);

	}
}
